@@ -11,10 +11,12 @@ const LIBPATH_env = "LD_LIBRARY_PATH"
 export libipopt
 const libipopt_path = "/usr/lib/libipopt.so.3"
 libipopt_handle = C_NULL
+get_libipopt_path() = libipopt_path
 const libipopt = "libipopt.so.3"
 export libipoptamplinterface
 const libipoptamplinterface_path = "/usr/lib/libipoptamplinterface.so.3"
 libipoptamplinterface_handle = C_NULL
+get_libipoptamplinterface_path() = libipoptamplinterface_path
 const libipoptamplinterface = "libipoptamplinterface.so.3"
 export amplexe
 const amplexe_path = "/usr/bin/ipopt"
